@@ -2,7 +2,7 @@
 package Moose::Meta::Attribute::Native::Trait::Hash;
 use Moose::Role;
 
-our $VERSION   = '1.13';
+our $VERSION   = '1.14';
 $VERSION = eval $VERSION;
 our $AUTHORITY = 'cpan:STEVAN';
 
@@ -47,7 +47,7 @@ Moose::Meta::Attribute::Native::Trait::Hash - Helper trait for HashRef attribute
           has_no_options => 'is_empty',
           num_options    => 'count',
           delete_option  => 'delete',
-          pairs          => 'kv',
+          option_pairs   => 'kv',
       },
   );
 
